@@ -10,7 +10,7 @@ our @EXPORT_OK = qw(
                        get_media_info
                );
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 our %SPEC;
 
@@ -47,7 +47,7 @@ Media::Info - Return information on media (music, video, etc) file/URL
 
 =head1 VERSION
 
-This document describes version 0.06 of Media::Info (from Perl distribution Media-Info), released on 2014-07-22.
+This document describes version 0.07 of Media::Info (from Perl distribution Media-Info), released on 2014-11-28.
 
 =head1 SYNOPSIS
 
@@ -134,11 +134,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
